import { graphql } from "@/gql";
import { EventFragment } from "@/gql/graphql";
import { getClient } from "@/app/client";
import { EventList } from "@/components/events/EventList";
import { Body } from "@/components/general/Body";
import Image from "next/image";
import { PersonList } from "@/components/people/PersonList";

export default async function Home() {
  const homeQuery = graphql(`
    query home {
      events: pages(contentType: "events.EventPage") {
        ...Event
      }
    }
  `);
  const { data, error } = await getClient().query(homeQuery, {});
  const events = (data?.events ?? []) as EventFragment[];

  return (
    <main className="site-main" id="main">
      <div>
        <EventList events={events} />
        <blockquote>«Hvor Glæden hersker, er alltid Fest»</blockquote>
        <div>
          <h2>Styret</h2>
          <PersonList />
        </div>
        <div>
          <h2>Administrasjonen</h2>
          <PersonList />
        </div>
        <p className="lead">
          Sed sodales nunc quis sapien malesuada, a faucibus turpis blandit.
          Suspendisse potenti. Sed auctor enim et augue dapibus, vitae laoreet
          lacus vulputate. Nulla sed finibus diam.
        </p>
        <Body />
      </div>
    </main>
  );
}
